@@ -3,8 +3,8 @@
 import pathlib
 
 import xlrd
-from alive_progress import alive_bar
 from openpyxl.workbook import Workbook
+from tqdm import tqdm
 
 
 def convert_xls_to_xlsx(src_file_path: pathlib.Path) -> None:
@@ -20,7 +20,7 @@ def convert_xls_to_xlsx(src_file_path: pathlib.Path) -> None:
         sheet_xls = book_xls.sheet_by_name(sheet_name)
         total_cells += sheet_xls.nrows * sheet_xls.ncols
 
-    with alive_bar(total_cells, title="Converting xls to xlsx", monitor=False, stats="{eta}") as progress_bar:
+    with tqdm(total=total_cells, desc="Converting xls to xlsx") as progress_bar:
         for sheet_index, sheet_name in enumerate(sheet_names):
             sheet_xls = book_xls.sheet_by_name(sheet_name)
             if sheet_index == 0:
@@ -32,6 +32,6 @@ def convert_xls_to_xlsx(src_file_path: pathlib.Path) -> None:
             for row in range(0, sheet_xls.nrows):
                 for col in range(0, sheet_xls.ncols):
                     sheet_xlsx.cell(row=row + 1, column=col + 1).value = sheet_xls.cell_value(row, col)
-                    progress_bar()  # pylint: disable=not-callable
+                    progress_bar.update(1)
 
     book_xlsx.save(dst_file_path)
